==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_eu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=eu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Estatistikak ezabatu', # MODIF

	// I
	'icone_evolution_visites' => 'Bisiten eboluzioa @visites@ bisitak',
	'icone_repartition_actuelle' => 'Oraingo banaketa erakutsi',
	'icone_repartition_visites' => 'Bisiten banaketa',
	'icone_statistiques_visites' => 'Bisiten estatistikak',
	'info_affichier_visites_articles_plus_visites' => 'Hasieratik gehien irakurritakoartikuluen bisitak argitaratu :',
	'info_comment_lire_tableau' => 'Nola irakurri lauki hau',
	'info_forum_statistiques' => 'Bisiten estatistikak',
	'info_popularite_2' => 'Gunearen arrakasta edo onarpena:',
	'info_popularite_3' => 'Arrakasta: @popularite@ Bisitak: @visites@',
	'info_popularite_5' => 'Arrakasta :',
	'info_question_vignettes_referer' => 'Estatistikak begiratzean, bisiten jatorrien guneen aurrebista ikusten ahal duzu',
	'info_question_vignettes_referer_oui' => 'Bisiten jatorrien guneen kapturak erakutsi',
	'info_visites' => 'bisitak :',
	'info_visites_plus_populaires' => 'Bisitak bistaratu artikulu hedatuenengatik eta argitaratutako azken artikuluengatik :',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Estatistikak kudeatu', # MODIF

	// O
	'onglet_origine_visites' => 'Bisiten jatorria',
	'onglet_repartition_debut' => 'hasieratik',
	'onglet_repartition_lang' => 'Hizkuntzakako banaketa',

	// T
	'texte_admin_effacer_stats' => 'Manu hunek gunearen bisiten estatistikei lotutako datu guziak ezabatzen ditu, artikuluen arrakasta barne.',
	'texte_comment_lire_tableau' => 'Artikuluaren heina, onarpenaren araberako sailkapenean, marjinean dago adierazita ;
Artikuluaren onarpena (berak jasoko duen eguneroko bisiten kopuruaren estimazio bat oraingokontsulta-erritmoa mantentzen bada) eta hasieratik jasotako bisiten kopurua saguak izenburuaren gainetik pasatzen denean agertzen den argibidean erakusten dira.',
	'texte_signification' => 'Barra ilunek metatutako sarrerak irudikatzen dituzte(azpiatalen erabatekoa), barra argiek atal bakoitzaren bisita guztiak.',
	'titre_evolution_visite' => 'Bisiten bilakaera',
	'titre_liens_entrants' => 'Eguneko gehitutako loturak',
	'titre_page_statistiques' => 'Atalez atal estatistikak',
	'titre_page_statistiques_visites' => 'Bisiten estatistikak'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_eu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=eu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Estatistikak ezabatu', # MODIF

	// I
	'icone_evolution_visites' => 'Bisiten eboluzioa @visites@ bisitak',
	'icone_repartition_actuelle' => 'Oraingo banaketa erakutsi',
	'icone_repartition_visites' => 'Bisiten banaketa',
	'icone_statistiques_visites' => 'Bisiten estatistikak',
	'info_affichier_visites_articles_plus_visites' => 'Hasieratik gehien irakurritakoartikuluen bisitak argitaratu :',
	'info_comment_lire_tableau' => 'Nola irakurri lauki hau',
	'info_forum_statistiques' => 'Bisiten estatistikak',
	'info_popularite_2' => 'Gunearen arrakasta edo onarpena:',
	'info_popularite_3' => 'Arrakasta: @popularite@ Bisitak: @visites@',
	'info_popularite_5' => 'Arrakasta :',
	'info_question_vignettes_referer' => 'Estatistikak begiratzean, bisiten jatorrien guneen aurrebista ikusten ahal duzu', # MODIF
	'info_question_vignettes_referer_oui' => 'Bisiten jatorrien guneen kapturak erakutsi',
	'info_visites' => 'bisitak :',
	'info_visites_plus_populaires' => 'Bisitak bistaratu artikulu hedatuenengatik eta argitaratutako azken artikuluengatik :',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Estatistikak kudeatu', # MODIF

	// O
	'onglet_origine_visites' => 'Bisiten jatorria',
	'onglet_repartition_debut' => 'hasieratik',
	'onglet_repartition_lang' => 'Hizkuntzakako banaketa',

	// T
	'texte_admin_effacer_stats' => 'Manu hunek gunearen bisiten estatistikei lotutako datu guziak ezabatzen ditu, artikuluen arrakasta barne.',
	'texte_comment_lire_tableau' => 'Artikuluaren heina, onarpenaren araberako sailkapenean, marjinean dago adierazita ;
Artikuluaren onarpena (berak jasoko duen eguneroko bisiten kopuruaren estimazio bat oraingokontsulta-erritmoa mantentzen bada) eta hasieratik jasotako bisiten kopurua saguak izenburuaren gainetik pasatzen denean agertzen den argibidean erakusten dira.',
	'texte_signification' => 'Barra ilunek metatutako sarrerak irudikatzen dituzte(azpiatalen erabatekoa), barra argiek atal bakoitzaren bisita guztiak.',
	'titre_evolution_visite' => 'Bisiten bilakaera',
	'titre_liens_entrants' => 'Eguneko gehitutako loturak',
	'titre_page_statistiques' => 'Atalez atal estatistikak',
	'titre_page_statistiques_visites' => 'Bisiten estatistikak'
);
